      SUBROUTINE USR_RATES_DES(NP, pM, IJK, DES_RATES)
      USE compar
      USE constant
      USE des_thermo
      USE des_rxns
      USE discretelement
      USE energy
      USE fldvar
      USE funits
      USE geometry
      USE indices
      USE param
      USE param1
      USE physprop
      USE rxns
      USE run
      !USE usr
      USE fun_avg
      USE functions

      USE parallel
      USE sendrecv
      USE toleranc
      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NP ! Global particle index
      INTEGER, INTENT(IN) :: pM ! Particle solid phase
      INTEGER, INTENT(IN) :: IJK ! Fluid Cell Index
      DOUBLE PRECISION, INTENT(OUT) :: DES_RATES(NO_OF_DES_RXNS) ! Reaction Rates
! Sa (m2), Kd (mol/(m2 Pa s)) Ref: Coupled deformation–flow analysis for methane hydrate extraction
      DOUBLE PRECISION Sa, pe, p_produc, Kd
      DOUBLE PRECISION :: Dp0
! Bounded phase temperatures (K)
      DOUBLE PRECISION xTg   ! gas phase
      DOUBLE PRECISION xTs   ! solids phase
! Gas phase pressure in KPa
      DOUBLE PRECISION Pg_KPa
! Gas phase concentrations (mol/m^3)
      DOUBLE PRECISION c_Br, c_Br2, c_NH4
! Partial pressures (KPa)
      DOUBLE PRECISION p_Br, p_Br2, p_NH4
! Diffusion coefficient for SiH2 (m^2/sec)
      DOUBLE PRECISION DIFF_SiH2
! SiH2 gas constant (KPa.m^3)/(kg-SiH2.K)
      DOUBLE PRECISION R_SiH2
! Calculate film diffusion resistance. (kg-SiH2/(KPa.sec.m^2)
      DOUBLE PRECISION K_f
! Apparent first order heterogeneous reation rate constant  (m/sec)
      DOUBLE PRECISION k_so
! Constant of hydroggen inhibition of heterogeneous reaction (1/KPa)
      DOUBLE PRECISION K_H
! Constant of silane inhibition of heterogeneous reaction (1/KPa)
      DOUBLE PRECISION KS
! Temporary values for reversible reactions
      DOUBLE PRECISION FWD, RVS, NET
      DOUBLE PRECISION, parameter :: c_Limiter = 0
!-------------------------------------------------------//
      INCLUDE 'species.inc'

! Calculate the bounded temperatures.
      xTg = max(min(T_g(IJK),   TMAX), 300.0d0)
      xTs = max(min(DES_T_s(NP), TMAX), 300.0d0)
! Convert gas pressure to KPa
      Pg_KPa = 1.0d-3 * P_g(IJK)  !  KPa
! Initialize partial pressures and concentrations.
      c_Br   = ZERO;   c_Br2= ZERO;    c_NH4 = ZERO;
      p_Br = ZERO;    p_Br2  = ZERO;   p_NH4 = ZERO;
      
! Calculate particle diameter.
      Dp0 = 2.0d0 * DES_RADIUS(NP)

! Particle surface area (m^2)
      Sa = Pi* Dp0 * Dp0   ! (m^2)
      pe=1.15*exp(49.3185-9459/T_g(IJK))
      Kd=124000*exp(-9400/T_g(IJK))
!      if (P_g(IJK)>pe) then
!     	DES_RATES(RX1)  = ZERO
!      else
! Units: kmol/s
!        DES_RATES(RX1)  = Kd*Sa*(pe-P_g(IJK))*0.1
!      endif
      if (time<0.5) then
	          DES_RATES(RX1)  = Kd*Sa*(pe-1D7)*0.1
      else
! Units: kmol/s
              DES_RATES(RX1)  = Kd*Sa*(pe-8D6)*0.1
      endif

!open(1,file="PVR.dat")
!write(1,*) "IJK=", IJK
!write(1,*) "Pe=", pe/1e6
!write(1,*) "P_g=", P_g(IJK)/1e6
!write(1,*) "T_g=", T_g(IJK)
!write(1,*) "rate=", DES_RATES(RX1)
! close(1)
!*X_g(IJK,H2)/(ONE+X_g(IJK,SiH4))
! Store the reaction rate for post processing.
      RETURN
      END SUBROUTINE USR_RATES_DES
